==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ListNetworkManagerDeploymentStatusPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ConfigurationType
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property deploymentTypes List of deployment types.
 * @property networkManagerName The name of the network manager.
 * @property regions List of locations.
 * @property resourceGroupName The name of the resource group.
 * @property skipToken Continuation token for pagination, capturing the next page size and offset, as well as the context of the query.
 * @property top An optional query parameter which specifies the maximum number of records to be returned by the server.
 */
public data class ListNetworkManagerDeploymentStatusPlainArgs(
    public val deploymentTypes: List<Either<String, ConfigurationType>>? = null,
    public val networkManagerName: String,
    public val regions: List<String>? = null,
    public val resourceGroupName: String,
    public val skipToken: String? = null,
    public val top: Int? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs =
        com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs.builder()
            .deploymentTypes(
                deploymentTypes?.let({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .networkManagerName(networkManagerName.let({ args0 -> args0 }))
            .regions(regions?.let({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .skipToken(skipToken?.let({ args0 -> args0 }))
            .top(top?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListNetworkManagerDeploymentStatusPlainArgs].
 */
@PulumiTagMarker
public class ListNetworkManagerDeploymentStatusPlainArgsBuilder internal constructor() {
    private var deploymentTypes: List<Either<String, ConfigurationType>>? = null

    private var networkManagerName: String? = null

    private var regions: List<String>? = null

    private var resourceGroupName: String? = null

    private var skipToken: String? = null

    private var top: Int? = null

    /**
     * @param value List of deployment types.
     */
    @JvmName("nykabutvrpndceue")
    public suspend fun deploymentTypes(`value`: List<Either<String, ConfigurationType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.deploymentTypes = mapped
    }

    /**
     * @param values List of deployment types.
     */
    @JvmName("kvinbpoyximvxhdu")
    public suspend fun deploymentTypes(vararg values: Either<String, ConfigurationType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deploymentTypes = mapped
    }

    /**
     * @param value The name of the network manager.
     */
    @JvmName("xghyuinojqvfyoww")
    public suspend fun networkManagerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkManagerName = mapped
    }

    /**
     * @param value List of locations.
     */
    @JvmName("lfnydytopdmitkyv")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.regions = mapped
    }

    /**
     * @param values List of locations.
     */
    @JvmName("jhxniyebnrueknvx")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.regions = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("qgvuxolbqdicqdlo")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Continuation token for pagination, capturing the next page size and offset, as well as the context of the query.
     */
    @JvmName("hbarkqifrggwoyue")
    public suspend fun skipToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.skipToken = mapped
    }

    /**
     * @param value An optional query parameter which specifies the maximum number of records to be returned by the server.
     */
    @JvmName("wwbbyfcgcrlljfkp")
    public suspend fun top(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.top = mapped
    }

    internal fun build(): ListNetworkManagerDeploymentStatusPlainArgs =
        ListNetworkManagerDeploymentStatusPlainArgs(
            deploymentTypes = deploymentTypes,
            networkManagerName = networkManagerName ?: throw PulumiNullFieldException("networkManagerName"),
            regions = regions,
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            skipToken = skipToken,
            top = top,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ListNetworkManagerDeploymentStatusPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ConfigurationType
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property deploymentTypes List of deployment types.
 * @property networkManagerName The name of the network manager.
 * @property regions List of locations.
 * @property resourceGroupName The name of the resource group.
 * @property skipToken Continuation token for pagination, capturing the next page size and offset, as well as the context of the query.
 * @property top An optional query parameter which specifies the maximum number of records to be returned by the server.
 */
public data class ListNetworkManagerDeploymentStatusPlainArgs(
    public val deploymentTypes: List<Either<String, ConfigurationType>>? = null,
    public val networkManagerName: String,
    public val regions: List<String>? = null,
    public val resourceGroupName: String,
    public val skipToken: String? = null,
    public val top: Int? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs =
        com.pulumi.azurenative.network.inputs.ListNetworkManagerDeploymentStatusPlainArgs.builder()
            .deploymentTypes(
                deploymentTypes?.let({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .networkManagerName(networkManagerName.let({ args0 -> args0 }))
            .regions(regions?.let({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .skipToken(skipToken?.let({ args0 -> args0 }))
            .top(top?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListNetworkManagerDeploymentStatusPlainArgs].
 */
@PulumiTagMarker
public class ListNetworkManagerDeploymentStatusPlainArgsBuilder internal constructor() {
    private var deploymentTypes: List<Either<String, ConfigurationType>>? = null

    private var networkManagerName: String? = null

    private var regions: List<String>? = null

    private var resourceGroupName: String? = null

    private var skipToken: String? = null

    private var top: Int? = null

    /**
     * @param value List of deployment types.
     */
    @JvmName("dsqnxuyndxwdlxbn")
    public suspend fun deploymentTypes(`value`: List<Either<String, ConfigurationType>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.deploymentTypes = mapped
    }

    /**
     * @param values List of deployment types.
     */
    @JvmName("eyjrxepnxohdycrb")
    public suspend fun deploymentTypes(vararg values: Either<String, ConfigurationType>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deploymentTypes = mapped
    }

    /**
     * @param value The name of the network manager.
     */
    @JvmName("gjanrdjoetqrorny")
    public suspend fun networkManagerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkManagerName = mapped
    }

    /**
     * @param value List of locations.
     */
    @JvmName("rdrvnbibewggrxrq")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.regions = mapped
    }

    /**
     * @param values List of locations.
     */
    @JvmName("icyqopuiahwwkenv")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.regions = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("noyepvvekdmolitc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Continuation token for pagination, capturing the next page size and offset, as well as the context of the query.
     */
    @JvmName("sayvugkpnsmevcga")
    public suspend fun skipToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.skipToken = mapped
    }

    /**
     * @param value An optional query parameter which specifies the maximum number of records to be returned by the server.
     */
    @JvmName("edprmspqyhtmhhxd")
    public suspend fun top(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.top = mapped
    }

    internal fun build(): ListNetworkManagerDeploymentStatusPlainArgs =
        ListNetworkManagerDeploymentStatusPlainArgs(
            deploymentTypes = deploymentTypes,
            networkManagerName = networkManagerName ?: throw PulumiNullFieldException("networkManagerName"),
            regions = regions,
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            skipToken = skipToken,
            top = top,
        )
}
